@@ -14,7 +14,7 @@ use crate::{
 };
 use serde::{Deserialize, Serialize, Serializer};
 use thiserror::Error;
-use xor_name::{Prefix, XorName};
+use xor_name::XorName;
 
 #[derive(Clone, Eq, PartialEq, Debug, Serialize, Deserialize)]
 #[allow(clippy::large_enum_variant)]
@@ -51,18 +51,6 @@ pub(crate) enum Proposal {
     // the same time as a single atomic operation without needing to cache anything.
     OurElders(Proven<SectionAuthorityProvider>),
 
-    // Proposal to update other section key.
-    TheirKey {
-        prefix: Prefix,
-        key: bls::PublicKey,
-    },
-
-    // Proposal to update other section's knowledge of our section.
-    TheirKnowledge {
-        prefix: Prefix,
-        key: bls::PublicKey,
-    },
-
     // Proposal to accumulate the message at the source (that is, our section) and then send it to
     // its destination.
     AccumulateAtSrc {
@@ -91,6 +79,7 @@ impl Proposal {
     }
 
     #[cfg(test)]
+    #[allow(unused)]
     pub fn as_signable(&self) -> SignableView {
         SignableView(self)
     }
@@ -106,8 +95,8 @@ impl<'a> Serialize for SignableView<'a> {
             Proposal::Offline(member_info) => member_info.serialize(serializer),
             Proposal::SectionInfo(info) => info.serialize(serializer),
             Proposal::OurElders(info) => info.proof.public_key.serialize(serializer),
-            Proposal::TheirKey { prefix, key } => (prefix, key).serialize(serializer),
-            Proposal::TheirKnowledge { prefix, key } => (prefix, key).serialize(serializer),
+            // Proposal::TheirKey { prefix, key } => (prefix, key).serialize(serializer),
+            // Proposal::TheirKnowledge { prefix, key } => (prefix, key).serialize(serializer),
             Proposal::AccumulateAtSrc { message, .. } => {
                 message.as_signable().serialize(serializer)
             }
@@ -146,8 +135,8 @@ mod tests {
     use super::*;
     use crate::{agreement, section};
     use anyhow::Result;
-    use rand::Rng;
     use std::fmt::Debug;
+    use xor_name::Prefix;
 
     #[test]
     fn serialize_for_signing() -> Result<()> {
@@ -164,18 +153,6 @@ mod tests {
         let proposal = Proposal::OurElders(proven_section_auth);
         verify_serialize_for_signing(&proposal, &new_pk)?;
 
-        // Proposal::TheirKey
-        let prefix = gen_prefix();
-        let key = bls::SecretKey::random().public_key();
-        let proposal = Proposal::TheirKey { prefix, key };
-        verify_serialize_for_signing(&proposal, &(prefix, key))?;
-
-        // Proposal::TheirKnowledge
-        let prefix = gen_prefix();
-        let key = bls::SecretKey::random().public_key();
-        let proposal = Proposal::TheirKnowledge { prefix, key };
-        verify_serialize_for_signing(&proposal, &(prefix, key))?;
-
         Ok(())
     }
 
@@ -195,16 +172,4 @@ mod tests {
 
         Ok(())
     }
-
-    fn gen_prefix() -> Prefix {
-        let mut rng = rand::thread_rng();
-        let mut prefix = Prefix::default();
-        let len = rng.gen_range(0, 5);
-
-        for _ in 0..len {
-            prefix = prefix.pushed(rng.gen());
-        }
-
-        prefix
-    }
 }
